<img align="right" width="400" src="https://github.com/elizabethmcd/metabolisHMM/blob/master/data/metabolisHMM-logo.png">

<br>
<br>
<br>

---

# metabolisHMM: a tool for exploration of microbial phylogenies and metabolic pathways

[metabolisHMM](https://github.com/elizabethmcd/metabolisHMM/wiki) is a pipeline for visualizing the distribution and evolutionary relationships using curated and custom Hidden Markov Model (HMM) profiles. Functional annotation of microbial genomes using HMMs is becoming increasingly popular over BLAST-based methods, however methods for rapidly visualizing and summarizing these results are lacking. This software automates the process of searching any set of metabolic markers that have an HMM profile against a set of genomes, and outputs phylogenies, summary statistics, and heatmap presence/absence visualizations. The metabolisHMM software is written in python and is available on [PyPi](https://pypi.org/project/metabolisHMM/).

Please see the [wiki](https://github.com/elizabethmcd/metabolisHMM/wiki) for installation and usage instructions. 